@@ -114,7 +114,7 @@ FutureResult<> CryFsBackend::mount(const Device &device,
     const auto cypher        = payload["cryfs-cipher"].toString();
     const auto shouldUpgrade = payload["cryfs-fs-upgrade"].toBool();
 
-    if (!dir.mkpath(device) || !dir.mkpath(mountPoint)) {
+    if (!dir.mkpath(device.data()) || !dir.mkpath(mountPoint.data())) {
         return errorResult(Error::BackendError, i18n("Failed to create directories, check your permissions"));
     }
 
@@ -124,21 +124,21 @@ FutureResult<> CryFsBackend::mount(const Device &device,
             cryfs({
                 "--cipher",
                 cypher,
-                device, // source directory to initialize cryfs in
-                mountPoint // where to mount the file system
+                device.data(), // source directory to initialize cryfs in
+                mountPoint.data() // where to mount the file system
             })
 
         // Cypher is not specified, use the default, whatever it is
         :shouldUpgrade ?
             cryfs({
-                device,     // source directory to initialize cryfs in
-                mountPoint, // where to mount the file system
+                device.data(),     // source directory to initialize cryfs in
+                mountPoint.data(), // where to mount the file system
                 "--allow-filesystem-upgrade"
             })
 
         : cryfs({
-                device,    // source directory to initialize cryfs in
-                mountPoint // where to mount the file system
+                device.data(),    // source directory to initialize cryfs in
+                mountPoint.data() // where to mount the file system
             })
 
         ;
@@ -147,6 +147,9 @@ FutureResult<> CryFsBackend::mount(const Device &device,
         const auto out = process->readAllStandardOutput();
         const auto err = process->readAllStandardError();
 
+        qDebug() << "OUT: " << out;
+        qDebug() << "ERR: " << err;
+
         const auto exitCode = (ExitCode) process->exitCode();
 
         auto upgradeFileSystem = [this, device, mountPoint, payload] {
@@ -168,15 +171,15 @@ FutureResult<> CryFsBackend::mount(const Device &device,
         };
 
         return
+            err.contains("'nonempty'") ?
+                Result<>::error(Error::CommandError,
+                                i18n("The mount point directory is not empty, refusing to open the vault")) :
+
             // If all went well, just return success
             (process->exitStatus() == QProcess::NormalExit && exitCode == ExitCode::Success) ?
                 Result<>::success() :
 
             // If we tried to mount into a non-empty location, report
-            err.contains("'nonempty'") ?
-                Result<>::error(Error::CommandError,
-                                i18n("The mount point directory is not empty, refusing to open the vault")) :
-
             exitCode == ExitCode::WrongPassword ?
                 Result<>::error(Error::BackendError,
                                 i18n("You entered the wrong password")) :
